# Arc Research Institute State Model Non-Commercial License

**_Last Updated: June 23, 2025_**

Arc Research Institute (“**Licensor**”) is releasing certain materials collectively defined below as the “**State Model**”.  This license (the “**License**”) is between Licensor and any individual or legal entity exercising permissions granted under this License (“**You**”).

By downloading, copying, executing, or otherwise exercising any permission granted by this License or using the State Model, You acknowledge that You accept and agree to be bound by the terms and conditions of this License.  If use of the State Model is within the scope of Your employment, You hereby represent that you are fully authorized to enter into this Agreement on behalf of any such employer.

Licensor may make changes to this License. The “_Last Updated_” date above indicates when this License was last changed.  The amended License will be effective immediately, and Your continued use of the State Model after such update will confirm Your acceptance of the changes.  If You do not agree to the amended License, You must immediately stop using the State Model.

## 1. Definitions

1.1  “**Commercial Entity**” means any natural person, legal entity, organization, or institution that is for-profit, or otherwise not a Non-Commercial Entity.

1.2  “**Derivative Work**” means any modification of, work based upon, or derived from, the State Model or any portion thereof, including adaptations, fine-tunings, adjusted model weights, distilled or pruned versions, additional training, or any other alteration, transformation, or integration, including use as a prior, of the State Model or any part of it.

1.3  “**Non-Commercial Entity**” means a (a) government body or (b) a natural person, academic institution, research institute, or other entity registered with relevant tax authorities as a not-for-profit organization that, in each (a) and (b) above, does not own or control or is not owned or controlled by and is not acting with or on behalf of a Commercial Entity.

1.4  “**Non-Commercial Purpose**” means a purpose that is not undertaken for direct or indirect monetary compensation, financial consideration, or any other commercial undertaking or advantage.  For the purposes of this License, research, development, or educational activities engaged in or sponsored by a Commercial Entity (whether or not performed by a Non-Commercial Entity or otherwise undertaken for a purpose not associated with monetary compensation, financial consideration or other commercial undertaking or advantage) are not Non-Commercial Purposes.

1.5  “**Output**” means any results, data, or other material generated by execution of the unmodified State Model or a Derivative Work.

1.6  “**State Model**” includes, individually and collectively, the pretrained model (_i.e._, the model code combined with the trained model weights), model weights, documentation, and any other files released by Licensor under this License (provided that source code and object code are licensed under a separate license made available by Licensor).

## 2.	Grant of Rights

2.1  **License**  Subject to the terms and conditions of this License, Licensor hereby grants You a personal, worldwide, royalty-free, non-exclusive, irrevocable (except as provided in Section 8), non-sublicensable license: (a) to use, copy, modify, and display the State Model; (b) to create Derivative Works and Outputs; (c) to reproduce, distribute, and make publicly available (i) the State Model and any Derivative Work, each subject to Section 3 (Redistribution Conditions), and (ii) any Output; and (d) under the Licensor’s patent rights covering the State Model, to make, use, import, and otherwise exploit the State Model and any Derivative Works, each (a) through (c)(i) and (d), solely for Non-Commercial Purposes.

2.2  **Patent Infringement**  If You initiate patent litigation (including a cross-claim or counterclaim in a lawsuit) alleging that the State Model or a Derivative Work infringes a patent, this  License to You is terminated as of the date such litigation is filed.

2.3  **Reservation of Rights**.  All rights other than those expressly granted to You herein are reserved by Licensor. 

## 3. Redistribution Conditions

If You redistribute the State Model or any Derivative Work, You must (a) include a complete, unaltered copy of this License; (b) keep intact all original copyright, license, and disclaimer notices; and (c) provide prominent notice stating that the redistributed State Model is governed by this License.  If You redistribute the State Model, any Derivative Work or any Output, You must also include a prominent and readable citation to the State Model research paper: Adduri, A. et al. (2025) Predicting cellular responses to perturbation across diverse contexts with State.  You may choose to license a Derivative Work or Output under different terms and conditions, provided that the limitations and restrictions herein (including, in the case of a Derivative Work, the Non-Commercial Purpose) remain in substance and effect.

## 4. Restrictions

4.1  You may not use or distribute the State Model, any or Derivative Work for any purpose other than Non-Commercial Purposes, unless You first obtain a separate, express, written license from Licensor granting such rights.  If you wish to inquire about such separate license, you may contact <legal@arcinsitute.org>.

4.2  You may not remove, obfuscate, or alter any copyright, trademark, citation or other proprietary notice included in the State Model.

4.3  You must comply with all applicable laws and regulations, including export-control and sanctions regimes, in connection with Your use of the State Model and any Derivative Work or Output.

4.4  If You elect to collect or process personal data, health data or any other regulated data using the State Model or any Derivative Work, You are solely responsible for compliance with all data-protection, privacy, and related laws.

## 5.	 Feedback

If You provide Licensor with ideas, suggestions, or improvements regarding the State Model (“**Feedback**”), Licensor may incorporate such Feedback without obligation or restriction, and You hereby irrevocably assign to Licensor all right, title, and interest in and to such Feedback and all intellectual property rights therein and thereto.  To the extent any rights in and to such Feedback cannot be assigned by You, You hereby grants to Licensor a nonexclusive, worldwide, perpetual, irrevocable, transferable, sublicensable, royalty-free, fully paid-up license to use, practice, and otherwise exercise the Feedback without restriction.

## 6. Trademarks 

This License does not grant permission to use the trade names, trademarks, service marks, or product names of the Licensor, except as required for reasonable and customary use in describing the origin of the State Model and reproducing the content of the license as required herein.

## 7. Disclaimer of Warranty; Limitation of Liability

THE STATE MODEL, ANY DERIVATIVE WORK, AND ANY OUTPUT ARE PROVIDED “AS IS” AND “WITH ALL FAULTS,” WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NON-INFRINGEMENT, OR THAT OPERATION OF THE STATE MODEL WILL BE UNINTERRUPTED OR ERROR-FREE.  TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, LICENSOR SHALL NOT BE LIABLE UNDER ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY, OR OTHERWISE, FOR ANY INDIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL, OR EXEMPLARY DAMAGES ARISING OUT OF OR RELATED TO THIS LICENSE OR THE USE OF THE STATE MODEL, DERIVATIVE WORKS, OR OUTPUTS, EVEN IF LICENSOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.  LICENSOR’S TOTAL AGGREGATE LIABILITY UNDER THIS LICENSE SHALL NOT EXCEED TWENTY U.S. DOLLARS (USD $20).

## 8.	 Termination

8.1  This License and the rights granted herein terminate automatically without notice if You breach Sections 2, 3, or 4.  Upon termination, You shall cease all use, reproduction, and distribution of the State Model, any Derivative Work, and any Output, and Sections 2.3, 4.4, 5, 7, 8.2, and 9 shall remain in effect.

8.2  Termination shall not affect any third-party’s legitimate possession, under this License, of copies of the State Model, Derivative Works, or Outputs obtained from You prior to termination, provided such third party is itself in full compliance with this License.

## 9.	 Miscellaneous

9.1  **Governing Law**.  This License shall be governed by and construed in accordance with the laws of the state of California, excluding its or any other jurisdiction’s conflict-of-laws principles. Venue for any disputes related to this License shall be in the federal courts in Santa Clara County, California and You and Licensor hereby agree to the exclusive jurisdiction of such courts.

9.2  **Severability**.  If any provision of this License is held to be unenforceable, such provision shall be reformed only to the extent necessary to make it enforceable, and the remaining provisions shall remain in full force and effect.

9.3  **No Waiver**.  Failure by Licensor to enforce any provision of this License shall not constitute a waiver of future enforcement of that or any other provision.

9.4  **Entire Agreement**.  This License constitutes the entire agreement between the parties with respect to the State Model and supersedes all prior or contemporaneous understandings, whether written or oral, regarding such subject matter. References herein to “including” will be interpreted to mean “including but not limited to” and any examples provided are illustrative and not intended to be the sole examples of a particular concept.

